Struct Occasion
pub struct Occasion { /* private fields */ }Expand description
An occasion within a subject’s dataset
An Occasion represents a distinct period of data collection for a subject, such as a hospital visit or dosing regimen. It contains events (doses, observations) and time-varying covariates.
Implementations
impl Occasion
impl Occasion
pub fn events(&self) -> &[Event]
pub fn events(&self) -> &[Event]
Get a vector of references to all events in this occasion
Returns
A slice of all events in this occasion
pub fn add_covariate(&mut self, name: String, covariate: Covariate)
pub fn add_covariate(&mut self, name: String, covariate: Covariate)
Add a covariate to this occasion
Arguments
name- Name of the covariatecovariate- The covariate to add
pub fn covariates(&self) -> &Covariates
pub fn covariates(&self) -> &Covariates
Get a reference to the covariates for this occasion
Returns
Reference to the occasion’s covariates, if any
pub fn covariates_mut(&mut self) -> &mut Covariates
pub fn covariates_mut(&mut self) -> &mut Covariates
Get a mutable refernce to the covariates for this occasion
Returns
Reference to the occasion’s covariates, if any
pub fn add_observation(
&mut self,
time: f64,
value: f64,
outeq: usize,
errorpoly: Option<ErrorPoly>,
censored: Censor,
)
pub fn add_observation( &mut self, time: f64, value: f64, outeq: usize, errorpoly: Option<ErrorPoly>, censored: Censor, )
Add an Observation event to the Occasion
pub fn add_missing_observation(&mut self, time: f64, outeq: usize)
pub fn add_missing_observation(&mut self, time: f64, outeq: usize)
Add a missing Observation event to the Occasion
pub fn add_observation_with_error(
&mut self,
time: f64,
value: f64,
outeq: usize,
errorpoly: ErrorPoly,
censored: Censor,
)
pub fn add_observation_with_error( &mut self, time: f64, value: f64, outeq: usize, errorpoly: ErrorPoly, censored: Censor, )
Add a missing Observation with a custom ErrorPoly to the Occasion
This is useful if you want a different weight for the observation
pub fn add_infusion(
&mut self,
time: f64,
amount: f64,
input: usize,
duration: f64,
)
pub fn add_infusion( &mut self, time: f64, amount: f64, input: usize, duration: f64, )
pub fn events_mut(&mut self) -> &mut Vec<Event>
pub fn events_mut(&mut self) -> &mut Vec<Event>
Get a mutable reference to the events
pub fn events_iter_mut(&mut self) -> IterMut<'_, Event>
pub fn events_iter_mut(&mut self) -> IterMut<'_, Event>
Get a mutable iterator to the events
impl Occasion
impl Occasion
pub fn nca_with_dose(
&self,
dose_amount: f64,
route: Route,
infusion_duration: Option<f64>,
options: &NCAOptions,
) -> Result<NCAResult, NCAError>
pub fn nca_with_dose( &self, dose_amount: f64, route: Route, infusion_duration: Option<f64>, options: &NCAOptions, ) -> Result<NCAResult, NCAError>
Run NCA with an explicit dose, overriding what is embedded in the occasion.
Use this when you want to supply or override dose amount, route, or infusion duration without modifying the underlying data.